@@ -26,7 +26,8 @@ class Pipeline:
 
         self._procedure_informer = ProcedureInformer()
 
-        self.event_listeners: Dict[EventListener, List[Type]] = {**other_listeners, **sinks, **transformers}
+        self.event_listeners: List[Tuple[EventListener, List[Type]]] = \
+            other_listeners.items() + sinks.items() + transformers.items()
         self.event_generators: List[EventGenerator] = \
             [self._procedure_informer] + other_generators + sources + list(transformers.keys())
 
@@ -34,14 +35,14 @@ class Pipeline:
         for generator in self.event_generators:
             generator.event_handler = InputLoggerEventBus(generator, self.bus)
         for listener in self.event_listeners:
-            for t in self.event_listeners[listener]:
-                self.bus.add_listener(listener, t)
+            for t in listener[1]:
+                self.bus.add_listener(listener[0], t)
 
         self.config: PipelineConfig = get_not_none(config, lambda: PipelineConfig())
         self.logger: Logger = self.config.logger
 
         all_pipeline_elements: Set[InternalPipelineElement] = set(self.event_generators).union(
-            self.event_listeners.keys())
+            [x[0] for x in self.event_listeners])
         for element in all_pipeline_elements:
             element.set_data_store(self.config.data_store)
             if element.logger is None:
